@@ -15,7 +15,7 @@ from ws4py.client.threadedclient import WebSocketClient
 
 from . import error
 
-_DEBUG = False
+_DEBUG = True
 
 RAMP_ENABLED = ['HBO_App',
                 '18a8aeaa-8e3d-4c24-b05d-da68394a3476_1',
